==> apache-iotdb-1.3.2-source-release.zip: apache-iotdb-1.3.2/iotdb-core/confignode/src/main/java/org/apache/iotdb/confignode/consensus/request/read/database/CountDatabasePlan.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.confignode.consensus.request.read.database;

import org.apache.iotdb.commons.path.PathPatternTree;
import org.apache.iotdb.commons.utils.BasicStructureSerDeUtil;
import org.apache.iotdb.confignode.consensus.request.ConfigPhysicalPlan;
import org.apache.iotdb.confignode.consensus.request.ConfigPhysicalPlanType;

import java.io.DataOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.Arrays;
import java.util.List;

public class CountDatabasePlan extends ConfigPhysicalPlan {

  private String[] storageGroupPattern;
  private PathPatternTree scope;

  public CountDatabasePlan() {
    super(ConfigPhysicalPlanType.CountDatabase);
  }

  public CountDatabasePlan(ConfigPhysicalPlanType type) {
    super(type);
  }

  public CountDatabasePlan(List<String> storageGroupPattern, PathPatternTree scope) {
    this();
    this.storageGroupPattern = storageGroupPattern.toArray(new String[0]);
    this.scope = scope;
  }

  public CountDatabasePlan(
      ConfigPhysicalPlanType type, List<String> storageGroupPattern, PathPatternTree scope) {
    super(type);
    this.storageGroupPattern = storageGroupPattern.toArray(new String[0]);
    this.scope = scope;
  }

  public String[] getDatabasePattern() {
    return storageGroupPattern;
  }

  public PathPatternTree getScope() {
    return scope;
  }

  @Override
  protected void serializeImpl(DataOutputStream stream) throws IOException {
    stream.writeShort(getType().getPlanType());

    stream.writeInt(storageGroupPattern.length);
    for (String node : storageGroupPattern) {
      BasicStructureSerDeUtil.write(node, stream);
    }
    scope.serialize(stream);
  }

  @Override
  protected void deserializeImpl(ByteBuffer buffer) {
    int length = buffer.getInt();
    storageGroupPattern = new String[length];
    for (int i = 0; i < length; i++) {
      storageGroupPattern[i] = BasicStructureSerDeUtil.readString(buffer);
    }
    scope = PathPatternTree.deserialize(buffer);
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    CountDatabasePlan that = (CountDatabasePlan) o;
    return Arrays.equals(storageGroupPattern, that.storageGroupPattern);
  }

  @Override
  public int hashCode() {
    return Arrays.hashCode(storageGroupPattern);
  }
}

==> apache-iotdb-1.3.6-source-release.zip: apache-iotdb-1.3.6/iotdb-core/confignode/src/main/java/org/apache/iotdb/confignode/consensus/request/read/database/CountDatabasePlan.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.confignode.consensus.request.read.database;

import org.apache.iotdb.commons.path.PathPatternTree;
import org.apache.iotdb.confignode.consensus.request.ConfigPhysicalPlanType;
import org.apache.iotdb.confignode.consensus.request.read.ConfigPhysicalReadPlan;

import java.util.Arrays;
import java.util.List;

public class CountDatabasePlan extends ConfigPhysicalReadPlan {

  private final String[] storageGroupPattern;
  private final PathPatternTree scope;

  public CountDatabasePlan(final List<String> storageGroupPattern, final PathPatternTree scope) {
    super(ConfigPhysicalPlanType.CountDatabase);
    this.storageGroupPattern = storageGroupPattern.toArray(new String[0]);
    this.scope = scope;
  }

  public CountDatabasePlan(
      final ConfigPhysicalPlanType type,
      final List<String> storageGroupPattern,
      final PathPatternTree scope) {
    super(type);
    this.storageGroupPattern = storageGroupPattern.toArray(new String[0]);
    this.scope = scope;
  }

  public String[] getDatabasePattern() {
    return storageGroupPattern;
  }

  public PathPatternTree getScope() {
    return scope;
  }

  @Override
  public boolean equals(final Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    final CountDatabasePlan that = (CountDatabasePlan) o;
    return Arrays.equals(storageGroupPattern, that.storageGroupPattern);
  }

  @Override
  public int hashCode() {
    return Arrays.hashCode(storageGroupPattern);
  }
}
